Google Calendar Baseline Report

### Secure Cloud Business Applications (SCuBA)

### Baseline Documents

# Google Calendar Baseline Report

Customer Name | Customer Domain | Customer ID | Report Date | Baseline Version | Tool Version
--- | --- | --- | --- | --- | ---
Cool Example Org | example.org | ABCDEFG | 06/26/2025 16:02:22 Pacific Daylight Time | 0.5 | v0.5.0

## CALENDAR-1 External Sharing Options

Control ID | Requirement | Result | Criticality | Details
--- | --- | --- | --- | ---
GWS.CALENDAR.1.1v0.5 | External Sharing Options for Primary Calendars SHALL be configured to "Only free/busy information (hide event details)." | Fail | Shall | The following OUs are non-compliant: Cool Example Org (group "Sophia Harris's group"): External sharing options for primary calendars is set to: Share all information, and allow managing of calendars
GWS.CALENDAR.1.2v0.5 | External sharing options for secondary calendars SHALL be configured to "Only free/busy information (hide event details)." | Pass | Shall | Requirement met in all OUs and groups.

## CALENDAR-2 External Invitations Warnings

Control ID | Requirement | Result | Criticality | Details
--- | --- | --- | --- | ---
GWS.CALENDAR.2.1v0.5 | External invitations warnings SHALL be enabled to prompt users before sending invitations. | Pass | Shall | Requirement met in all OUs and groups.

## CALENDAR-3 Calendar Interop Management

Control ID | Requirement | Result | Criticality | Details
--- | --- | --- | --- | ---
GWS.CALENDAR.3.1v0.5 | Calendar Interop SHOULD be disabled. | Pass | Should | Requirement met in all OUs and groups.
GWS.CALENDAR.3.2v0.5 | OAuth 2.0 SHALL be used in lieu of basic authentication to establish connectivity between tenants or organizations in cases where Calendar Interop is deemed necessary for agency mission fulfillment. | N/A | Shall/Not-Implemented | Currently not able to be tested automatically; please manually check.

## CALENDAR-4 Paid Appointments

Control ID | Requirement | Result | Criticality | Details
--- | --- | --- | --- | ---
GWS.CALENDAR.4.1v0.5 | Appointment Schedule with Payments SHALL be disabled. | Pass | Shall | Requirement met in all OUs and groups.